Memmem

Trait Memmem 

pub trait Memmem<'i, 'b, 'r, I: Input, const N: usize> {
    // Required method
    fn find_label(
        &mut self,
        first_block: Option<I::Block<'i, N>>,
        start_idx: usize,
        label: &StringPattern,
    ) -> Result<Option<(usize, I::Block<'i, N>)>, InputError>;
}
Classifier that can quickly find a member name in a byte stream.

Required Methods

fn find_label( &mut self, first_block: Option<I::Block<'i, N>>, start_idx: usize, label: &StringPattern, ) -> Result<Option<(usize, I::Block<'i, N>)>, InputError>

Find a member key identified by a given StringPattern.

  • first_block – optional first block to search; if not provided, the search will start at the next block returned by the underlying Input iterator.
  • start_idx – index of the start of search, either falling inside first_block, or at the start of the next block.
Errors

Errors when reading the underlying Input are propagated.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors