Structural

Enum Structural 

pub enum Structural {
    Closing(BracketType, usize),
    Colon(usize),
    Opening(BracketType, usize),
    Comma(usize),
}
Defines structural characters in JSON documents.

Variants



Closing(BracketType, usize)

Represents the closing square or curly brace, ‘]’ or ‘}’.



Colon(usize)

Represents the colon ‘:’ character.



Opening(BracketType, usize)

Represents the opening square or curly brace, ‘[’ or ‘{’.



Comma(usize)

Represents the comma ‘,’ character.

Implementations

Source

impl Structural

pub fn idx(self) -> usize

Returns the index of the character in the document, i.e. which byte it is counting from 0.

pub fn offset(self, amount: usize) -> Self

Add a given amount to the structural’s index.

Examples

let structural = Structural::Colon(42);
let offset_structural = structural.offset(10);

assert_eq!(structural.idx(), 42);
assert_eq!(offset_structural.idx(), 52);
pub fn is_closing(&self) -> bool

Check if the structural represents a closing character, i.e. a Closing with either of the BracketType variants.

Examples

let brace = Structural::Closing(BracketType::Curly, 42);
let bracket = Structural::Closing(BracketType::Square, 43);
let neither = Structural::Comma(44);

assert!(brace.is_closing());
assert!(bracket.is_closing());
assert!(!neither.is_closing());
pub fn is_opening(&self) -> bool

Check if the structural represents an opening character, i.e. an Opening with either of the BracketType variants.

Examples

let brace = Structural::Opening(BracketType::Curly, 42);
let bracket = Structural::Opening(BracketType::Square, 43);
let neither = Structural::Comma(44);

assert!(brace.is_opening());
assert!(bracket.is_opening());
assert!(!neither.is_opening());