Struct rsonpath::input::owned::OwnedBytes
source · pub struct OwnedBytes { /* private fields */ }Expand description
Input into a query engine.
Implementations
sourceimpl OwnedBytes
impl OwnedBytes
sourcepub fn as_borrowed(&self) -> BorrowedBytes<'_>
pub fn as_borrowed(&self) -> BorrowedBytes<'_>
Convert to BorrowedBytes.
sourcepub unsafe fn from_raw_parts(ptr: NonNull<u8>, size: usize) -> Self
pub unsafe fn from_raw_parts(ptr: NonNull<u8>, size: usize) -> Self
Create an instance of OwnedBytes from raw pointers.
Safety
This is highly unsafe, and requires similar invariants as stdlib’s Vec.
ptrmust have been allocated using the global allocator;ptrmust have been allocated with size equal tosize;- first
sizevalues thatptrpoints to must be correctly initialized instances ofu8. - the
sizemust be not more thanisize::MAX; ptrmust be aligned to theMAX_BLOCK_SIZEboundary;sizemust be divisible byMAX_BLOCK_SIZE.
Ownership of ptr is transferred to the resulting instance. You must ensure
there are no other mutable references to its contents and that the memory
is not deallocated.
sourcepub fn new<T: AsRef<[u8]>>(src: &T) -> Result<Self, InputError>
pub fn new<T: AsRef<[u8]>>(src: &T) -> Result<Self, InputError>
Copy a buffer of bytes and create a proper OwnedBytes instance.
The contents of the buffer will be copied and might be padded to
the MAX_BLOCK_SIZE boundary.
Errors
If the length of the buffer plus
the padding exceeds the system limit of isize::MAX, an InputError::AllocationSizeExceeded
error will be raised.
sourcepub unsafe fn new_unchecked<T: AsRef<[u8]>>(src: &T) -> Self
pub unsafe fn new_unchecked<T: AsRef<[u8]>>(src: &T) -> Self
Create a new instance of OwnedBytes from a buffer satisfying
all invariants.
Safety
The invariants are assumed, not checked. You must ensure that the buffer passed to this function:
- has length not exceeding the system cap of isize::MAX;
- is aligned to the
MAX_BLOCK_SIZEboundary; - has length divisible by
MAX_BLOCK_SIZE.