InputRecorder

Trait InputRecorder 

pub trait InputRecorder<B: Deref<Target = [u8]>> {
    // Required method
    fn record_block_start(&self, new_block: B);
}
Base trait of any recorder, one that can react to a block of input being processed.

Required Methods

fn record_block_start(&self, new_block: B)

Record that all processing of a block was started

The recorder may assume that only matches or terminators with indices pointing to the block that was last recorded as started are reported.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<B, S> InputRecorder<B> for NodesRecorder<'_, B, S>
where B: Deref<Target = [u8]>, S: Sink<Match>,

Source

impl<B: Deref<Target = [u8]>> InputRecorder<B> for CountRecorder

Source

impl<B: Deref<Target = [u8]>> InputRecorder<B> for EmptyRecorder

Source

impl<B: Deref<Target = [u8]>, S> InputRecorder<B> for ApproxSpanRecorder<'_, S>
where S: Sink<MatchSpan>,

Source

impl<B: Deref<Target = [u8]>, S> InputRecorder<B> for IndexRecorder<'_, S>
where S: Sink<MatchIndex>,