Borrows a slice of bytes of the input document.
Choose this implementation if:
- You already have the data loaded in-memory and it is properly aligned.
Performance characteristics
This type of input is the fastest to process for the engine, since there is no additional overhead from loading anything to memory.
Structs
- Input wrapping a borrowed [
[u8]] buffer. - Iterator over blocks of
BorrowedBytesof size exactlyN.