pub trait InputRecorder<B: Deref<Target = [u8]>> {
// Required method
fn record_block_start(&self, new_block: B);
}Expand description
Base trait of any recorder, one that can react to a block of input being processed.
Required Methods
Sourcefn record_block_start(&self, new_block: B)
fn record_block_start(&self, new_block: B)
Record that all processing of a block was started
The recorder may assume that only matches or terminators with indices pointing to the block that was last recorded as started are reported.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".